pub struct SamplerDesc {
pub min_filter: Filter,
pub mag_filter: Filter,
pub mip_filter: Filter,
pub wrap_mode: (WrapMode, WrapMode, WrapMode),
pub lod_bias: Lod,
pub lod_range: Range<Lod>,
pub comparison: Option<Comparison>,
pub border: PackedColor,
pub normalized: bool,
pub anisotropic: Anisotropic,
}Expand description
Specifies how to sample from an image. These are all the parameters available that alter how the GPU goes from a coordinate in an image to producing an actual value from the texture, including filtering/ scaling, wrap mode, etc.
Fields
min_filter: FilterMinification filter method to use.
mag_filter: FilterMagnification filter method to use.
mip_filter: FilterMip filter method to use.
wrap_mode: (WrapMode, WrapMode, WrapMode)Wrapping mode for each of the U, V, and W axis (S, T, and R in OpenGL speak).
lod_bias: LodThis bias is added to every computed mipmap level (N + lod_bias). For example, if it would select mipmap level 2 and lod_bias is 1, it will use mipmap level 3.
lod_range: Range<Lod>This range is used to clamp LOD level used for sampling.
comparison: Option<Comparison>Comparison mode, used primary for a shadow map.
border: PackedColorBorder color is used when one of the wrap modes is set to border.
normalized: boolSpecifies whether the texture coordinates are normalized.
anisotropic: AnisotropicAnisotropic filtering.
Implementations
Sourceimpl SamplerDesc
impl SamplerDesc
Sourcepub fn new(filter: Filter, wrap: WrapMode) -> SamplerDesc
pub fn new(filter: Filter, wrap: WrapMode) -> SamplerDesc
Create a new sampler description with a given filter method for all filtering operations and a wrapping mode, using no LOD modifications.